@@ -1,3 +1,4 @@
+
 #include "Hypridle.hpp"
 #include "../helpers/Log.hpp"
 #include "../config/ConfigManager.hpp"
@@ -54,18 +55,27 @@ void CHypridle::run() {
         exit(1);
     }
 
-    const auto RULES = g_pConfigManager->getRules();
+    static const auto IGNOREWAYLANDINHIBIT = g_pConfigManager->getValue<Hyprlang::INT>("general:ignore_wayland_inhibit");
+
+    const auto        RULES = g_pConfigManager->getRules();
     m_sWaylandIdleState.listeners.resize(RULES.size());
 
     Debug::log(LOG, "found {} rules", RULES.size());
 
     for (size_t i = 0; i < RULES.size(); ++i) {
-        auto&       l = m_sWaylandIdleState.listeners[i];
-        const auto& r = RULES[i];
-        l.onRestore   = r.onResume;
-        l.onTimeout   = r.onTimeout;
+        auto&       l   = m_sWaylandIdleState.listeners[i];
+        const auto& r   = RULES[i];
+        l.onRestore     = r.onResume;
+        l.onTimeout     = r.onTimeout;
+        l.ignoreInhibit = r.ignoreInhibit;
+
+        if (*IGNOREWAYLANDINHIBIT || r.ignoreInhibit)
+            l.notification =
+                makeShared<CCExtIdleNotificationV1>(m_sWaylandIdleState.notifier->sendGetInputIdleNotification(r.timeout * 1000 /* ms */, m_sWaylandState.seat->resource()));
+        else
+            l.notification =
+                makeShared<CCExtIdleNotificationV1>(m_sWaylandIdleState.notifier->sendGetIdleNotification(r.timeout * 1000 /* ms */, m_sWaylandState.seat->resource()));
 
-        l.notification = makeShared<CCExtIdleNotificationV1>(m_sWaylandIdleState.notifier->sendGetIdleNotification(r.timeout * 1000 /* ms */, m_sWaylandState.seat->resource()));
         l.notification->setData(&m_sWaylandIdleState.listeners[i]);
 
         l.notification->setIdled([this](CCExtIdleNotificationV1* n) { onIdled((CHypridle::SIdleListener*)n->data()); });
@@ -248,7 +258,7 @@ static void spawn(const std::string& args) {
 void CHypridle::onIdled(SIdleListener* pListener) {
     Debug::log(LOG, "Idled: rule {:x}", (uintptr_t)pListener);
     isIdled = true;
-    if (g_pHypridle->m_iInhibitLocks > 0) {
+    if (g_pHypridle->m_iInhibitLocks > 0 && !pListener->ignoreInhibit) {
         Debug::log(LOG, "Ignoring from onIdled(), inhibit locks: {}", g_pHypridle->m_iInhibitLocks);
         return;
     }
@@ -265,7 +275,7 @@ void CHypridle::onIdled(SIdleListener* pListener) {
 void CHypridle::onResumed(SIdleListener* pListener) {
     Debug::log(LOG, "Resumed: rule {:x}", (uintptr_t)pListener);
     isIdled = false;
-    if (g_pHypridle->m_iInhibitLocks > 0) {
+    if (g_pHypridle->m_iInhibitLocks > 0 && !pListener->ignoreInhibit) {
         Debug::log(LOG, "Ignoring from onResumed(), inhibit locks: {}", g_pHypridle->m_iInhibitLocks);
         return;
     }
@@ -288,16 +298,22 @@ void CHypridle::onInhibit(bool lock) {
     }
 
     if (m_iInhibitLocks == 0 && isIdled) {
-        const auto RULES = g_pConfigManager->getRules();
+        static const auto IGNOREWAYLANDINHIBIT = g_pConfigManager->getValue<Hyprlang::INT>("general:ignore_wayland_inhibit");
 
+        const auto        RULES = g_pConfigManager->getRules();
         for (size_t i = 0; i < RULES.size(); ++i) {
             auto&       l = m_sWaylandIdleState.listeners[i];
             const auto& r = RULES[i];
 
             l.notification->sendDestroy();
 
-            l.notification =
-                makeShared<CCExtIdleNotificationV1>(m_sWaylandIdleState.notifier->sendGetIdleNotification(r.timeout * 1000 /* ms */, m_sWaylandState.seat->resource()));
+            if (*IGNOREWAYLANDINHIBIT || r.ignoreInhibit)
+                l.notification =
+                    makeShared<CCExtIdleNotificationV1>(m_sWaylandIdleState.notifier->sendGetInputIdleNotification(r.timeout * 1000 /* ms */, m_sWaylandState.seat->resource()));
+            else
+                l.notification =
+                    makeShared<CCExtIdleNotificationV1>(m_sWaylandIdleState.notifier->sendGetIdleNotification(r.timeout * 1000 /* ms */, m_sWaylandState.seat->resource()));
+
             l.notification->setData(&m_sWaylandIdleState.listeners[i]);
 
             l.notification->setIdled([this](CCExtIdleNotificationV1* n) { onIdled((CHypridle::SIdleListener*)n->data()); });
@@ -313,7 +329,7 @@ void CHypridle::onLocked() {
     m_isLocked = true;
 
     static const auto LOCKCMD = g_pConfigManager->getValue<Hyprlang::STRING>("general:on_lock_cmd");
-    if (*LOCKCMD)
+    if (!std::string{*LOCKCMD}.empty())
         spawn(*LOCKCMD);
 
     if (m_inhibitSleepBehavior == SLEEP_INHIBIT_LOCK_NOTIFY)
@@ -328,7 +344,7 @@ void CHypridle::onUnlocked() {
         inhibitSleep();
 
     static const auto UNLOCKCMD = g_pConfigManager->getValue<Hyprlang::STRING>("general:on_unlock_cmd");
-    if (*UNLOCKCMD)
+    if (!std::string{*UNLOCKCMD}.empty())
         spawn(*UNLOCKCMD);
 }
 
@@ -551,7 +567,13 @@ void CHypridle::setupDBUS() {
 
             m_sDBUSState.screenSaverServiceConnection->addMatch("type='signal',sender='org.freedesktop.DBus',interface='org.freedesktop.DBus',member='NameOwnerChanged'",
                                                                 ::handleDbusNameOwnerChanged);
-        } catch (std::exception& e) { Debug::log(ERR, "Couldn't connect to session dbus\nerr: {}", e.what()); }
+        } catch (sdbus::Error& e) {
+            if (e.getName() == sdbus::Error::Name{"org.freedesktop.DBus.Error.FileExists"}) {
+                Debug::log(ERR, "Another service is already providing the org.freedesktop.ScreenSaver interface");
+                Debug::log(ERR, "Is hypridle already running?");
+            } else
+                Debug::log(ERR, "Failed to connect to ScreenSaver service\nerr: {}", e.what());
+        }
     }
 
     systemConnection.reset();
@@ -570,6 +592,11 @@ void CHypridle::handleInhibitOnDbusSleep(bool toSleep) {
 }
 
 void CHypridle::inhibitSleep() {
+    if (!m_sDBUSState.login) {
+        Debug::log(WARN, "Can't inhibit sleep. Dbus logind interface is not available.");
+        return;
+    }
+
     if (m_sDBUSState.sleepInhibitFd.isValid()) {
         Debug::log(WARN, "Called inhibitSleep, but previous sleep inhibitor is still active!");
         m_sDBUSState.sleepInhibitFd.reset();
